@@ -20,9 +20,8 @@ import logging
 import traceback
 import tempfile
 import hashlib
-import importlib_metadata
 from contextlib import ExitStack
-from typing import Optional, List, Generator, Dict, Any, Tuple, Callable
+from typing import Optional, Generator, Dict, Any, Tuple, Callable
 from . import config
 from .cache import CallCache
 from .._util import compose_coroutines
