@@ -71,15 +71,20 @@ def run_local_task(
         # provision run directory and log file
         run_dir = provision_run_dir(task.name, run_dir, last_link=not _run_id_stack)
         logfile = os.path.join(run_dir, "task.log")
-        fh = cleanup.enter_context(
+        cleanup.enter_context(
             LoggingFileHandler(
                 logger,
                 logfile,
-                json=(
-                    cfg["logging"].get_bool("json") if cfg.has_option("logging", "json") else False
-                ),
             )
         )
+        if cfg.has_option("logging", "json") and cfg["logging"].get_bool("json"):
+            cleanup.enter_context(
+                LoggingFileHandler(
+                    logger,
+                    logfile + ".json",
+                    json=True,
+                )
+            )
         logger.notice(  # pyre-fixme
             _(
                 "task start",
@@ -96,7 +101,6 @@ def run_local_task(
         if not _run_id_stack:
             cache = _cache or cleanup.enter_context(new_call_cache(cfg, logger))
             cache.flock(logfile, exclusive=True)  # no containing workflow; flock task.log
-            cache.flock(run_dir, exclusive=True)
         else:
             cache = _cache
         assert cache
@@ -539,8 +543,6 @@ def _try_task(
                     and interruptions < cfg["task_runtime"].get_int("_mock_interruptions")
                 ):
                     raise Interrupted("mock interruption") from None
-                if terminating():
-                    raise Terminated()
         except Exception as exn:
             if isinstance(exn, Interrupted) and interruptions < max_interruptions:
                 logger.error(
@@ -553,7 +555,11 @@ def _try_task(
                     )
                 )
                 interruptions += 1
-            elif not isinstance(exn, (Terminated, DockerBuildError)) and retries < max_retries:
+            elif (
+                not isinstance(exn, (Terminated, DockerBuildError))
+                and retries < max_retries
+                and not terminating()
+            ):
                 logger.error(
                     _(
                         "failed task will be retried",
