@@ -633,15 +633,20 @@ def run_local_workflow(
     logger = logging.getLogger(".".join(logger_id))
     logfile = os.path.join(run_dir, "workflow.log")
     with ExitStack() as cleanup:
-        fh = cleanup.enter_context(
+        cleanup.enter_context(
             LoggingFileHandler(
                 logger,
                 logfile,
-                json=(
-                    cfg["logging"].get_bool("json") if cfg.has_option("logging", "json") else False
-                ),
             )
         )
+        if cfg.has_option("logging", "json") and cfg["logging"].get_bool("json"):
+            cleanup.enter_context(
+                LoggingFileHandler(
+                    logger,
+                    logfile + ".json",
+                    json=True,
+                )
+            )
         logger.notice(  # pyre-fixme
             _(
                 "workflow start",
@@ -688,7 +693,6 @@ def run_local_workflow(
 
             assert not _run_id_stack
             cache.flock(logfile, exclusive=True)  # flock top-level workflow.log
-            cache.flock(run_dir, exclusive=True)
             try:
                 # log version into workflow.log
                 version = "v" + importlib_metadata.version("miniwdl")
@@ -730,7 +734,7 @@ def run_local_workflow(
             )
         except:
             _statusbar.abort()
-            if not _run_id_stack:
+            if not _run_id_stack and cfg["scheduler"].get_bool("fail_fast"):
                 # if we're the top-level worfklow, signal abort to anything still running
                 # concurrently on the thread pools (SIGUSR1 will be picked up by
                 # TerminationSignalFlag)
